==> bastille_1.3.0.orig.tar.gz: bastille-1.3.0.orig/Bastille/Printing.pm <==
# Copyright (C) 1999, 2000 Jay Beale
# Licensed under the GNU General Public License

package Bastille::Printing;
use lib "/usr/lib";

use Bastille::API;
@ENV="";
$ENV{PATH}="";
$ENV{CDPATH}=".";
$ENV{BASH_ENV}="";

### TO DO: Figure out how to disable printing in other distros...
### TO DO: Figure out what to do about MiscellaneousDaemons and Printing
### TO DO:    when porting to other distros...

#######################################################################
##                                lpr/lpd                            ##
#######################################################################

#&DisallowRemotePrinting;
&DisableLprdrm;
#&ConfigLPRng;


sub DisallowRemotePrinting { 
   &ActionLog("# sub DisallowRemotePrinting\n");
   # Disallow remote printing if this won't be a print server

   ## This is the default configuration for Redhat6.0 -- watch for this
   ## though, when porting to other distributions.
}

sub DisableLprdrm {

   # If this machine will never be used for printing, disable lpr/lpd/lprm
   # altogether...

    if (&getGlobalConfig("Printing","printing") eq "Y") {
	&ActionLog("# sub DisableLprdrm\n");
	&B_chmod(0500,&getGlobal('BIN',"lpr"));
	&B_chmod(0500,&getGlobal('BIN',"lprm"));
	&B_chmod(0500,&getGlobal('BIN',"lpq"));
	unless ( $GLOBAL_DISTRO =~ "^HP-UX") {
	    &B_chkconfig_off("lpd");
	}
	else {
	    &B_ch_rc ('LP',&getGlobal('FILE', 'chkconfig_lpd'));
	}
    }
}

sub ConfigLPRng {
   #&ActionLog("# sub ConfigLPRng\n");
   #### does someone want to come up with a LPRng configuration ?
}

1;

==> bastille_2.1.1.orig.tar.gz: bastille-2.1.1/Bastille/Printing.pm <==
# Copyright (C) 1999, 2000 Jay Beale
# Licensed under the GNU General Public License

package Bastille::Printing;
use lib "/usr/lib";

use Bastille::API;
@ENV="";
$ENV{PATH}="";
$ENV{CDPATH}=".";
$ENV{BASH_ENV}="";

### TO DO: Figure out how to disable printing in other distros...
### TO DO: Figure out what to do about MiscellaneousDaemons and Printing
### TO DO:    when porting to other distros...

#######################################################################
##                                lpr/lpd                            ##
#######################################################################

#&DisallowRemotePrinting;
&DisableLprdrm;
&DisableCUPSD;
#&ConfigLPRng;


sub DisallowRemotePrinting { 
   &ActionLog("# sub DisallowRemotePrinting\n");
   # Disallow remote printing if this won't be a print server

   ## This is the default configuration for Redhat6.0 -- watch for this
   ## though, when porting to other distributions.
}

sub DisableLprdrm {

   # If this machine will never be used for printing, disable lpr/lpd/lprm
   # altogether...

    if (&getGlobalConfig("Printing","printing") eq "Y") {
	&ActionLog("# sub DisableLprdrm\n");
	&B_chmod(0500,&getGlobal('BIN',"lpr"));
	&B_chmod(0500,&getGlobal('BIN',"lprm"));
	&B_chmod(0500,&getGlobal('BIN',"lpq"));
	unless ( &GetDistro =~ "^HP-UX") {
	    &B_chkconfig_off("lpd");
	}
	else {
	    &B_ch_rc ('LP',&getGlobal('FILE', 'chkconfig_lpd'));
	}
    }
}

sub DisableCUPSD {

   # If this machine will never be used for printing, disable lpr/lpd/lprm
   # altogether...

    if (&getGlobalConfig("Printing","printing_osx") eq "Y") {
	&ActionLog("# sub DisableCUPSD\n");
	&B_chmod(0500,&getGlobal('BIN',"lpr"));
	&B_chmod(0500,&getGlobal('BIN',"lprm"));
	&B_chmod(0500,&getGlobal('BIN',"lpq"));
	if (&GetDistro =~ /^OSX/) {
	    &B_replace_line(&getGlobal('FILE','hostconfig'),'^CUPS\=\-YES\-',"CUPS=-NO-\n");
	}
    }
    elsif (&getGlobalConfig("Printing","printing_cups") eq "Y") {
	&ActionLog("# sub DisableCUPSD\n");
	&B_chmod(0500,&getGlobal('BIN',"lpr"));
	&B_chmod(0500,&getGlobal('BIN',"lprm"));
	&B_chmod(0500,&getGlobal('BIN',"lpq"));
	&B_chmod(0500,&getGlobal('BIN',"lpstat"));
	&B_chmod(0500,&getGlobal('BIN',"lppasswd"));
	my $distro = &GetDistro;
	unless (&GetDistro =~ /^OSX/) {
	    &B_chkconfig_off("cups");
	}
    }
}

sub ConfigLPRng {
   #&ActionLog("# sub ConfigLPRng\n");
   #### does someone want to come up with a LPRng configuration ?
}

1;
